@@ -1,59 +1,59 @@
-#########v1.2.5#########
-import urllib.request
 import json
 
-from youtubesearchpython.__requesthandler import requesthandler
-from youtubesearchpython.playlist__scripthandler import scripthandler
+from youtubesearchpython.__requesthandler import RequestHandler
+from youtubesearchpython.playlist__scripthandler import ScriptHandler
 
 
-class SearchPlaylists(requesthandler, scripthandler):
-
-    #########https://github.com/alexmercerind/youtube-search-python#########
-
+class SearchPlaylists(RequestHandler, ScriptHandler):
+    '''
+    Search for playlists in YouTube.
+    Parameters
+    ----------
+    keyword : str
+        Used as a query to search for playlists in YouTube.
+    offset : int, optional
+        Offset for result pages on YouTube. Defaults to 1.
+    mode : str
+        Search result mode. Can be 'json', 'dict' or 'list'.
+    maxResults : int, optional
+        Maximum number of playlist results. Defaults to 20.
+    Methods
+    -------
+    result()
+        Returns the playlists fetched from YouTube by search().
+    '''
     networkError = False
     validResponse = False
 
     def __init__(self, keyword, offset = 1, mode = "json", max_results = 20):
 
-        #########CLASS CONSTRUCTOR#########
-
-        #########Setting Feilds#########
-
         self.offset = offset
         self.mode = mode
         self.keyword = keyword
         self.max_results = max_results
         self.searchPreferences = "EgIQAw%3D%3D"
+        self.main()
 
-        #########Executing Entry Point Of Class#########
-
-        self.exec()
-
-    def exec(self):
-        
-        #########exec PROPERTY#########
-
+    def main(self):
         self.request()
-
         if self.networkError:
             self.networkError = True
         else:
             self.scriptResponseHandler()
 
     def result(self):
-
-        #########result PROPERTY#########
-
-        #########Checking for network error and returning None to the user in case of it.#########
-
+        '''
+        Returns
+        -------
+        None, str, dict, list
+            Returns playlist results from YouTube. Returns None, if network error occurs.
+        '''
         if self.networkError:
             return None
 
         else:
 
             result = []
-            
-            #########JSON Result Handling.#########
 
             if self.mode in ["json", "dict"]:
 
@@ -71,8 +71,6 @@ class SearchPlaylists(requesthandler, scripthandler):
                 else:
                     return {"search_result": result}
             
-            #########List Result Handling.#########
-
             elif self.mode == "list":
                 
                 for index in range(len(self.ids)):
