@@ -1,60 +1,57 @@
-#########v1.2.5#########
-import html
+import sys
+
+if sys.version_info[0] == 2:
+    import HTMLParser
+else:
+    import html
 
 
-class pagehandler:
-
+class PageHandler:
     def pageResponseHandler(self):
-
-        #########pageResponseHandler PROPERTY#########
-
-        #########This property is later called in the another property exec() of the class.   #########
-
-        temp = 0
-
-        #########Defining Result Arrays.#########
-
         self.links = []
         self.ids = []
         self.titles = []
         self.channels = []
+        self.channelIds = []
         self.views = []
         self.durations = []
         self.thumbnails = []
 
-        #########Transversing Through Network Request Array.#########
-        
         self.pageSource = self.page.split()
 
+        if sys.version_info < (2, 8):
+            html = HTMLParser.HTMLParser()
+
         for index in range(0, len(self.pageSource) - 1, 1):
 
             element = self.pageSource[index]
             elementNext = self.pageSource[index+1]
             elementPrev = self.pageSource[index-1]
 
-            #########Setting Video View Counts.#########
+            ''' Setting Video View Counts. '''
 
             if element == "views</li></ul></div><div":
                 viewCount = 0
                 for character in elementPrev:
                     if character.isnumeric():
                         viewCount = viewCount * 10 + int(character)
-                self.views+=[viewCount]            
+                self.views+=[viewCount]
+                ''' Unimplemented as this response is not recieved now '''
+                self.channelIds+=[""]         
 
-            #########Setting Video Links, IDs And Thumbnails.#########
+            ''' Setting Video Links, IDs And Thumbnails. '''
 
             if element[0:15] == 'href="/watch?v=' and len('www.youtube.com'+element[6:len(element)-1]) == 35:
                 thumbnailbuffer = []
                 modes = ["default", "hqdefault", "mqdefault", "sddefault", "maxresdefault"]
-                temp+=1
-                if temp%2 ==0:
+                if element[15:len(element) - 1] not in self.ids:
                     self.links+=['https://www.youtube.com'+element[6:len(element)-1]]
                     self.ids+=[element[15:len(element) - 1]]
                     for mode in modes:
                         thumbnailbuffer+=["https://img.youtube.com/vi/" + element[15:len(element) - 1] + "/" + mode + ".jpg"]
                     self.thumbnails+=[thumbnailbuffer]
 
-            #########Setting Video Channels.#########
+            ''' Setting Video Channels. '''
 
             if (element[-15:] == '</a>&nbsp;<span' and self.pageSource[index+1] == 'title="Verified"') or (element[-14:] == '</a></div><div' and self.pageSource[index+1] == 'class="yt-lockup-meta'):
                 channelBuffer = ""
@@ -73,7 +70,7 @@ class pagehandler:
                         channelBuffer+=channelText[index]
                 self.channels+= [channelBuffer]
 
-            #########Setting Video Durations.#########
+            ''' Setting Video Durations. '''
 
             if element[0:19] == 'aria-hidden="true">' and element[19].isnumeric():
                 buffer = ""
@@ -87,7 +84,7 @@ class pagehandler:
                         break
                 self.durations+=[buffer[1::]]
 
-            #########Setting Video Titles.#########
+            ''' Setting Video Titles. '''
 
             if (element[0:23] == 'data-sessionlink="itct=') and (elementNext[0:7] == 'title="'):
                 buffer = ""
