@@ -1,33 +1,21 @@
-#########v1.2.5#########
-
-
-class scripthandler:
-
+class ScriptHandler:
     def scriptResponseHandler(self):
-
-        #########scriptResponseHandler PROPERTY#########
-
-        #########This property is later called in the another property exec() of the class.   #########
-
-        temp = 0
-
-        #########Defining Result Arrays.#########
-
         self.links = []
         self.ids = []
         self.titles = []
         self.channels = []
+        self.channelIds = []
         self.views = []
         self.durations = []
         self.thumbnails = []
 
-        #########Transversing Through Network Request Array.#########
+        indexValue = 0
 
         self.pageSource = self.page.split('":"')
 
         for index in range(0, len(self.pageSource) - 1, 1):
             
-            #########Setting Video Durations And View Counts.#########
+            ''' Setting Video Durations And View Counts. '''
 
             if self.pageSource[index][-14:] == '}},"simpleText' and self.pageSource[index+1][-28:] == '"viewCountText":{"simpleText':
                 durationBuffer = ""
@@ -37,41 +25,47 @@ class scripthandler:
                         durationBuffer+=character
                     else:
                         break
-                for character in self.pageSource[index+2].split()[0]:
+                for character in self.pageSource[index+2]:
                     if character.isnumeric():
                         viewCountBuffer = viewCountBuffer * 10 + int(character)
+                    elif character == '"':
+                        break
                 self.durations[-1] = durationBuffer
                 self.views[-1] = viewCountBuffer
 
-            #########Setting Video Links, IDs And Thumbnails.#########
+            ''' Setting Video Links, IDs And Thumbnails. '''
 
-            if self.pageSource[index][-98:] == '"commandMetadata":{"webCommandMetadata":{}},"addToPlaylistCommand":{"openMiniplayer":true,"videoId':
-                temp+=1
-                if temp % 2 == 0:
-                    id = self.pageSource[index+1][0:11]
-                    thumbnailbuffer = []
-                    modes = ["default", "hqdefault", "mqdefault", "sddefault", "maxresdefault"]
-                    self.ids+=[id]
-                    self.links+=['https://www.youtube.com/watch?v='+ id]
-                    for mode in modes:
-                        thumbnailbuffer+=["https://img.youtube.com/vi/" + id + "/" + mode + ".jpg"]
-                    self.thumbnails+=[thumbnailbuffer]
+            if self.pageSource[index][0:9] == '/watch?v=':
+                id = self.pageSource[index][9:20]
+                modes = ["default", "hqdefault", "mqdefault", "sddefault", "maxresdefault"]
+                self.ids+=[id]
+                self.links+=['https://www.youtube.com/watch?v='+ id]
+                thumbnailbuffer = []
+                for mode in modes:
+                    thumbnailbuffer+=["https://img.youtube.com/vi/" + id + "/" + mode + ".jpg"]
+                self.thumbnails+=[thumbnailbuffer]
             
-            #########Setting Video Titles.#########
+            ''' Setting Video Titles. '''
 
             if self.pageSource[index][-23:] == '"title":{"runs":[{"text' and self.pageSource[index+1][-44:] == '"accessibility":{"accessibilityData":{"label':
                 titleBuffer = ""
-                for character in self.pageSource[index+1]:
-                    if character!= '"':
-                        titleBuffer+=character
+                for subIndex in range(len(self.pageSource[index+1])):
+                    if self.pageSource[index+1][subIndex: subIndex+2] != '}]':
+                        ''' For getting rid of " written as \" in JSON '''
+                        if self.pageSource[index+1][subIndex] == '"' and self.pageSource[index+1][subIndex+1: subIndex+3] != '}]':
+                            titleBuffer = titleBuffer[:-1]
+                        titleBuffer+=self.pageSource[index+1][subIndex]
                     else:
+                        titleBuffer = titleBuffer[:-1]
                         break
                 self.titles+=[titleBuffer.replace("\\u0026", "&")]
+
                 self.views+=["LIVE"]
                 self.durations+=["LIVE"]
                 self.channels+= [""]
+                self.channelIds+=[""]
 
-            #########Setting Video Channels.#########
+            ''' Setting Video Channels. '''
 
             if self.pageSource[index][-32:] == '"longBylineText":{"runs":[{"text' and self.pageSource[index+1][-42:] == '"navigationEndpoint":{"clickTrackingParams':
                 channelBuffer = ""
@@ -82,6 +76,7 @@ class scripthandler:
                         break
                 try:
                     self.channels[-1] = channelBuffer.replace("\\u0026", "&")
+                    self.channelIds[-1] = self.pageSource[index+5].split('"')[0]
                 except:
                     pass
 
