@@ -1,46 +1,45 @@
-#########v1.2.5#########
-import urllib.request
 import json
 
-from youtubesearchpython.__requesthandler import requesthandler
-from youtubesearchpython.videos__pagehandler import pagehandler
-from youtubesearchpython.videos__scripthandler import scripthandler
+from youtubesearchpython.__requesthandler import RequestHandler
+from youtubesearchpython.videos__pagehandler import PageHandler
+from youtubesearchpython.videos__scripthandler import ScriptHandler
 
 
-class SearchVideos(requesthandler, pagehandler, scripthandler):
-
-    #########https://github.com/alexmercerind/youtube-search-python#########
-
+class SearchVideos(RequestHandler, PageHandler, ScriptHandler):
+    '''
+    Search for videos in YouTube.
+    Parameters
+    ----------
+    keyword : str
+        Used as a query to search for videos in YouTube.
+    offset : int, optional
+        Offset for result pages on YouTube. Defaults to 1.
+    mode : str
+        Search result mode. Can be 'json', 'dict' or 'list'.
+    maxResults : int, optional
+        Maximum number of video results. Defaults to 20.
+    Methods
+    -------
+    search()
+        Searches for the videos in YouTube
+    result()
+        Returns the videos fetched from YouTube by search().
+    '''
     networkError = False
     validResponse = False
 
     def __init__(self, keyword, offset = 1, mode = "json", max_results = 20):
-
-        #########CLASS CONSTRUCTOR#########
-
-        #########Setting Feilds#########
-
         self.offset = offset
         self.mode = mode
         self.keyword = keyword
         self.max_results = max_results
         self.searchPreferences = "EgIQAQ%3D%3D"
+        self.main()
 
-        #########Executing Entry Point Of Class#########
-
-        self.exec()
-
-    def exec(self):
-        
-        #########exec PROPERTY#########
-
-        #########Calling network request.#########
-
+    def main(self):
         self.request()
-
         if self.networkError:
             self.networkError = True
-
         else:
 
             if not self.validResponse:
@@ -50,11 +49,12 @@ class SearchVideos(requesthandler, pagehandler, scripthandler):
                 self.pageResponseHandler()
 
     def result(self):
-
-        #########result PROPERTY#########
-
-        #########Checking for network error and returning None to the user in case of it.#########
-
+        '''
+        Returns
+        -------
+        None, str, dict, list
+            Returns video results from YouTube. Returns None, if network error occurs.
+        '''
         if self.networkError:
             return None
 
@@ -62,8 +62,6 @@ class SearchVideos(requesthandler, pagehandler, scripthandler):
 
             result = []
             
-            #########JSON Result Handling.#########
-
             if self.mode in ["json", "dict"]:
 
                 for index in range(len(self.ids)):
@@ -75,7 +73,8 @@ class SearchVideos(requesthandler, pagehandler, scripthandler):
                         "channel": self.channels[index],
                         "duration": self.durations[index],
                         "views": self.views[index],
-                        "thumbnails": self.thumbnails[index]
+                        "thumbnails": self.thumbnails[index],
+                        "channelId": self.channelIds[index],
                     }
                     result+=[result_index]
 
@@ -83,9 +82,7 @@ class SearchVideos(requesthandler, pagehandler, scripthandler):
                     return json.dumps({"search_result": result}, indent=4)
                 else:
                     return {"search_result": result}
-            
-            #########List Result Handling.#########
-
+                    
             elif self.mode == "list":
                 
                 for index in range(len(self.ids)):
@@ -97,7 +94,8 @@ class SearchVideos(requesthandler, pagehandler, scripthandler):
                             self.channels[index],
                             self.durations[index],
                             self.views[index],
-                            self.thumbnails[index]
+                            self.thumbnails[index],
+                            self.channelIds[index],
                     ]
                     result+=[list_index]
                 
